File formats — Pootle 2.9.0b2 documentation

# File formats

Pootle supports many file formats through the powerful Translate Toolkit API. The Toolkit also provides several format converters for other formats, this will allow you to host a lot of translatable content on Pootle.

All these formats can be downloaded for offline use/or translation (for example in Virtaal). We recommend Virtaal for offline translation. They can also be downloaded in XLIFF format.

## Bilingual formats

These formats are translation files that include the source and target language in one file.

- Gettext PO
- XLIFF
- Qt TS
- TBX
- TMX